package jdk.javadoc.internal.doclets.formats.html.resources;

public final class standard_de extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "doclet.All_Modules", "Alle Module" },
            { "doclet.All_Packages", "Alle Packages" },
            { "doclet.Annotation_Interface_Hierarchy", "Annotationsschnittstellenhierarchie" },
            { "doclet.Annotation_Interface_Members", "Annotationsschnittstellenelemente" },
            { "doclet.Annotation_Interfaces", "Annotationsschnittstellen" },
            { "doclet.Annotation_Type_Hierarchy", "Annotationstyphierarchie" },
            { "doclet.Annotation_Type_Members", "Annotationstypelemente" },
            { "doclet.Annotation_Types", "Annotationstypen" },
            { "doclet.ClassUse_Annotation", "Klassen in {1} mit Annotationen vom Typ {0}" },
            { "doclet.ClassUse_Classes.in.0.used.by.1", "Von {1} verwendete Klassen in {0}" },
            { "doclet.ClassUse_ConstructorAnnotations", "Konstruktoren in {1} mit Annotationen vom Typ {0}" },
            { "doclet.ClassUse_ConstructorArgs", "Konstruktoren in {1} mit Parametern vom Typ {0}" },
            { "doclet.ClassUse_ConstructorArgsTypeParameters", "Konstruktorparameter in {1} mit Typargumenten vom Typ {0}" },
            { "doclet.ClassUse_ConstructorParameterAnnotations", "Konstruktorparameter in {1} mit Annotationen vom Typ {0}" },
            { "doclet.ClassUse_ConstructorThrows", "Konstruktoren in {1}, die {0} ausl\u00F6sen" },
            { "doclet.ClassUse_Field", "Felder in {1}, die deklariert sind als {0}" },
            { "doclet.ClassUse_FieldAnnotations", "Felder in {1} mit Annotationen vom Typ {0}" },
            { "doclet.ClassUse_FieldTypeParameter", "Felder in {1} mit Typparametern vom Typ {0}" },
            { "doclet.ClassUse_ImplementingClass", "Klassen in {1}, die {0} implementieren" },
            { "doclet.ClassUse_ImplementsTypeParameter", "Klassen in {1}, die Schnittstellen mit Typargumenten vom Typ {0} implementieren" },
            { "doclet.ClassUse_MethodAnnotations", "Methoden in {1} mit Annotationen vom Typ {0}" },
            { "doclet.ClassUse_MethodArgs", "Methoden in {1} mit Parametern vom Typ {0}" },
            { "doclet.ClassUse_MethodArgsTypeParameters", "Methodenparameter in {1} mit Typargumenten vom Typ {0}" },
            { "doclet.ClassUse_MethodParameterAnnotations", "Methodenparameter in {1} mit Annotationen vom Typ {0}" },
            { "doclet.ClassUse_MethodReturn", "Methoden in {1}, die {0} zur\u00FCckgeben" },
            { "doclet.ClassUse_MethodReturnTypeParameter", "Methoden in {1}, die Typen mit Argumenten vom Typ {0} zur\u00FCckgeben" },
            { "doclet.ClassUse_MethodThrows", "Methoden in {1}, die {0} ausl\u00F6sen" },
            { "doclet.ClassUse_MethodTypeParameter", "Methoden in {1} mit Typparametern vom Typ {0}" },
            { "doclet.ClassUse_No.usage.of.0", "Keine Verwendung von {0}" },
            { "doclet.ClassUse_PackageAnnotation", "Packages mit Annotationen vom Typ {0}" },
            { "doclet.ClassUse_Packages.that.use.0", "Packages, die {0} verwenden" },
            { "doclet.ClassUse_Subclass", "Unterklassen von {0} in {1}" },
            { "doclet.ClassUse_SubclassTypeParameter", "Unterklassen mit Typargumenten vom Typ {0} in {1}" },
            { "doclet.ClassUse_Subinterface", "Unterschnittstellen von {0} in {1}" },
            { "doclet.ClassUse_SubinterfaceTypeParameter", "Unterschnittstellen mit Typargumenten vom Typ {0} in {1}" },
            { "doclet.ClassUse_Title", "Verwendungen von {0}" },
            { "doclet.ClassUse_TypeParameter", "Klassen in {1} mit Typparametern vom Typ {0}" },
            { "doclet.ClassUse_Uses.of.0.in.1", "Verwendungen von {0} in {1}" },
            { "doclet.Class_Hierarchy", "Klassenhierarchie" },
            { "doclet.Constructor_for", "Konstruktor f\u00FCr {0}" },
            { "doclet.Contents", "Inhalt" },
            { "doclet.Declared_Using_Preview", "{0} wird mit {1} deklariert, einem Vorschaufeature der Programmiersprache Java ({2})." },
            { "doclet.Declared_Using_Preview.SEALED", "Verschl\u00FCsselte Klassen" },
            { "doclet.Declared_Using_Preview.SEALED_PERMITS", "Verschl\u00FCsselte Klassen" },
            { "doclet.Deprecated_API", "Veraltete API" },
            { "doclet.Deprecated_API_Checkbox_All_Releases", "Alle" },
            { "doclet.Deprecated_API_Checkbox_Label", "Veraltete API anzeigen in:" },
            { "doclet.Deprecated_API_Checkbox_Other_Releases", "Sonstige" },
            { "doclet.Deprecated_Elements", "Veraltete {0}" },
            { "doclet.Deprecated_Elements_Release_Column_Header", "Veraltet in" },
            { "doclet.Deprecated_In_Release", "Veraltet in {0}" },
            { "doclet.Description", "Beschreibung" },
            { "doclet.Description_From_Class", "Beschreibung aus Klasse kopiert:" },
            { "doclet.Description_From_Interface", "Beschreibung aus Schnittstelle kopiert:" },
            { "doclet.Detail", "Details:" },
            { "doclet.Element", "Element" },
            { "doclet.Element_in", "Element in {0}" },
            { "doclet.Enclosing_Class", "Umschlie\u00DFende Klasse:" },
            { "doclet.Enclosing_Interface", "Umschlie\u00DFende Schnittstelle:" },
            { "doclet.Enum_Class_Hierarchy", "Enum-Klassenhierarchie" },
            { "doclet.Enum_Hierarchy", "Enum-Hierarchie" },
            { "doclet.Enum_constant_in", "Enum-Konstante in {0}" },
            { "doclet.Error_copying_legal_notices", "Fehler beim Kopieren der rechtlichen Hinweise: {0}" },
            { "doclet.Error_in_grouplist", "Ung\u00FCltige Option -group: {0} {1}" },
            { "doclet.Error_invalid_path_for_legal_notices", "Ung\u00FCltiger Pfad \"{0}\" f\u00FCr rechtliche Hinweise: {1}" },
            { "doclet.External_Specification", "Externe Spezifikation" },
            { "doclet.External_Specifications", "Externe Spezifikationen" },
            { "doclet.External_Specifications.All_Specifications", "Alle Spezifikationen" },
            { "doclet.External_Specifications.no-host", "Lokal" },
            { "doclet.File_error", "Fehler beim Lesen der Datei: {0}" },
            { "doclet.Functional_Interface", "Funktionsschnittstelle:" },
            { "doclet.Functional_Interface_Message", "Dies ist eine funktionale Schnittstelle, die somit als Zuweisungsziel f\u00FCr einen Lambdaausdruck oder eine Methodenreferenz verwendet werden kann." },
            { "doclet.Generated_Docs_Untitled", "Generierte Dokumentation (unbenannt)" },
            { "doclet.Groupname_already_used", "In der Option -group wird der Gruppenname bereits verwendet: {0}" },
            { "doclet.Help", "Hilfe" },
            { "doclet.Help_Sub_Nav", "Hilfe:" },
            { "doclet.Hierarchy_For_All_Packages", "Hierarchie f\u00FCr alle Packages" },
            { "doclet.Hierarchy_For_Package", "Hierarchie f\u00FCr Package {0}" },
            { "doclet.Hierarchy_For_Unnamed_Package", "Hierarchie f\u00FCr unbenanntes Package" },
            { "doclet.Href_Annotation_Interface_Title", "Annotationsschnittstelle in {0}" },
            { "doclet.Href_Annotation_Title", "Annotation in {0}" },
            { "doclet.Href_Class_Or_Interface_Title", "Klasse oder Schnittstelle in {0}" },
            { "doclet.Href_Class_Title", "Klasse in {0}" },
            { "doclet.Href_Enum_Class_Title", "Enum-Klasse in {0}" },
            { "doclet.Href_Enum_Title", "Enum in {0}" },
            { "doclet.Href_Interface_Title", "Schnittstelle in {0}" },
            { "doclet.Href_Type_Param_Title", "Typparameter in {0}" },
            { "doclet.Implementing_Classes", "Alle bekannten Implementierungsklassen:" },
            { "doclet.Index", "Index" },
            { "doclet.Inheritance_Tree", "Vererbungsbaum" },
            { "doclet.Interface_Hierarchy", "Schnittstellenhierarchie" },
            { "doclet.Interfaces", "Schnittstellen" },
            { "doclet.Invalid_URL", "ung\u00FCltige URL: {0}" },
            { "doclet.MalformedURL", "Nicht wohlgeformte URL: {0}" },
            { "doclet.Method_in", "Methode in {0}" },
            { "doclet.Module", "Modul" },
            { "doclet.Module_Sub_Nav", "Modul:" },
            { "doclet.Navigation", "Navigation" },
            { "doclet.New_API", "Neue API" },
            { "doclet.New_API_Checkbox_All_Releases", "Alle" },
            { "doclet.New_API_Checkbox_Label", "Hinzugef\u00FCgte API anzeigen in:" },
            { "doclet.New_Elements", "Neue {0}" },
            { "doclet.New_Elements_Release_Column_Header", "Hinzugef\u00FCgt in" },
            { "doclet.New_Label", "Neu" },
            { "doclet.NoFrames_specified", "Die Option --no-frames wird nicht mehr ben\u00F6tigt und wird m\u00F6glicherweise\nin einem zuk\u00FCnftigen Release entfernt." },
            { "doclet.No_Non_Deprecated_Classes_To_Document", "Keine zu dokumentierenden nicht veralteten Klassen gefunden." },
            { "doclet.No_Script_Message", "JavaScript ist im Browser deaktiviert." },
            { "doclet.None", "Kein Wert" },
            { "doclet.Open_Module", "Modul \u00F6ffnen" },
            { "doclet.Option_date_not_valid", "Wert f\u00FCr \"--date\" nicht g\u00FCltig: {0}" },
            { "doclet.Option_date_out_of_range", "Wert f\u00FCr \"--date\" au\u00DFerhalb des g\u00FCltigen Bereichs: {0}" },
            { "doclet.Other_Packages", "Andere Packages" },
            { "doclet.Overrides", "Setzt au\u00DFer Kraft:" },
            { "doclet.Overview", "\u00DCberblick" },
            { "doclet.Package", "Package" },
            { "doclet.Package_Hierarchies", "Packagehierarchien:" },
            { "doclet.Package_Sub_Nav", "Package:" },
            { "doclet.PreviewAPI", "{0} bezieht sich auf mindestens eine Vorschau-API: {1}." },
            { "doclet.PreviewLeadingNote", "{0} basiert auf Vorschaufeatures der Java-Plattform:" },
            { "doclet.PreviewPlatformLeadingNote", "{0} ist eine Vorschau-API der Java-Plattform." },
            { "doclet.PreviewTrailingNote1", "Programme k\u00F6nnen {0} nur verwenden, wenn Vorschaufeatures aktiviert sind." },
            { "doclet.PreviewTrailingNote2", "Vorschaufeatures k\u00F6nnen in k\u00FCnftigen Releases entfernt oder zu permanenten Features der Java-Plattform hochgestuft werden." },
            { "doclet.Preview_API", "Vorschau-API" },
            { "doclet.Preview_API_Checkbox_Label", "Vorschau-API anzeigen f\u00FCr:" },
            { "doclet.Preview_API_Checkbox_Toggle_All", "Alle umschalten" },
            { "doclet.Preview_JEP_URL", "https://openjdk.org/jeps/{0}" },
            { "doclet.Preview_Label", "Vorschau" },
            { "doclet.Preview_Mark", "PREVIEW" },
            { "doclet.Record_Class_Hierarchy", "Datensatz-Klassenhierarchie" },
            { "doclet.Record_component_in", "Komponente von {0} erfassen" },
            { "doclet.ReferencedIn", "Referenziert in" },
            { "doclet.ReflectivePreviewAPI", "{0} bezieht sich auf mindestens eine reflektive Vorschau-API: {1}." },
            { "doclet.ReflectivePreviewPlatformLeadingNote", "{0} ist eine reflektive Vorschau-API der Java-Plattform." },
            { "doclet.Resource_error", "Fehler beim Lesen der Ressource: {0}" },
            { "doclet.RestrictedLeadingNote", "{0} ist eine eingeschr\u00E4nkte Methode der Java-Plattform." },
            { "doclet.RestrictedTrailingNote1", "Programme k\u00F6nnen {0} nur verwenden, wenn der Zugriff auf eingeschr\u00E4nkte Methoden aktiviert ist." },
            { "doclet.RestrictedTrailingNote2", "Eingeschr\u00E4nkte Methoden sind nicht sicher und k\u00F6nnen bei falscher Verwendung die JVM zum Absturz bringen oder zu einer Besch\u00E4digung des Arbeitsspeichers f\u00FChren." },
            { "doclet.Restricted_Mark", "RESTRICTED" },
            { "doclet.Restricted_Methods", "Eingeschr\u00E4nkte Methoden" },
            { "doclet.Same_element_name_used", "Elementname oder Muster zweimal verwendet: {0}" },
            { "doclet.Search_tag_in", "Tag suchen in {0}" },
            { "doclet.Section", "Abschnitt" },
            { "doclet.Skip_navigation_links", "Navigations-Links \u00FCberspringen" },
            { "doclet.Specification", "Spezifikation" },
            { "doclet.Specified_By", "Angegeben von:" },
            { "doclet.Static_method_in", "Statische Methode in {0}" },
            { "doclet.Static_variable_in", "Statische Variable in {0}" },
            { "doclet.Subclasses", "Bekannte direkte Unterklassen:" },
            { "doclet.Subinterfaces", "Alle bekannten Unterschnittstellen:" },
            { "doclet.Summary", "\u00DCbersicht:" },
            { "doclet.System_Property", "Systemeigenschaft" },
            { "doclet.Terminally_Deprecated", "Endg\u00FCltig veraltet" },
            { "doclet.Terminally_Deprecated_Elements", "Endg\u00FCltig veraltete Elemente" },
            { "doclet.Terminally_Deprecated_In_Release", "Endg\u00FCltig veraltet in {0}" },
            { "doclet.Toggle_navigation_links", "Navigationslinks umschalten" },
            { "doclet.Tree", "Baum" },
            { "doclet.URL_error", "Fehler beim Abrufen der URL: {0}" },
            { "doclet.Unnamed_Package", "Unbenanntes Package" },
            { "doclet.UsesDeclaredUsingPreview", "{0} bezieht sich auf mindestens einen Typ, der mit einem Vorschaufeature der Programmiersprache Java deklariert wird: {1}." },
            { "doclet.Variable_in", "Variable in {0}" },
            { "doclet.Window_ClassUse_Header", "Verwendungsweise von {0} {1}" },
            { "doclet.Window_Class_Hierarchy", "Klassenhierarchie" },
            { "doclet.Window_Deprecated_List", "Veraltete Liste" },
            { "doclet.Window_Help_title", "API-Hilfe" },
            { "doclet.Window_New_List", "Neue API-Liste" },
            { "doclet.Window_Overview_Summary", "\u00DCberblick" },
            { "doclet.Window_Preview_List", "Vorschauliste" },
            { "doclet.Window_Restricted_List", "Liste eingeschr\u00E4nkter Methoden" },
            { "doclet.Window_Search_title", "Suchen" },
            { "doclet.Window_Single_Index", "Index" },
            { "doclet.Window_Source_title", "Quellcode" },
            { "doclet.Window_Split_Index", "{0}-Index" },
            { "doclet.also", "auch" },
            { "doclet.annotation_interface_members", "Annotationsschnittstellenelemente" },
            { "doclet.annotation_interfaces", "Annotationsschnittstellen" },
            { "doclet.annotation_type_members", "Annotationstypelemente" },
            { "doclet.annotation_types", "Annotationstypen" },
            { "doclet.build_version", "Standard-Doclet-Version {0}" },
            { "doclet.extSpec.spec.has.multiple.titles", "{1} verschiedene Titel in @spec-Tags f\u00FCr die externe Spezifikation bei {0}" },
            { "doclet.extSpec.title.for.multiple.specs", "Der Titel \"{0}\" wird f\u00FCr {1} verschiedene externe Spezifikationen in @spec-Tags verwendet" },
            { "doclet.extSpec.title.url", "Titel: \"{0}\", URL: {1}" },
            { "doclet.extSpec.url.title", "URL: {0}, Titel: \"{1}\"" },
            { "doclet.footer_specified", "Die Option -footer wird nicht mehr unterst\u00FCtzt und wird ignoriert.\nSie wird m\u00F6glicherweise in einem zuk\u00FCnftigen Release entfernt." },
            { "doclet.help.all_classes.body", "Die Seite {0} enth\u00E4lt einen alphabetischen Index aller Klassen und Schnittstellen in der Dokumentation, einschlie\u00DFlich Annotationsschnittstellen, Enum-Klassen und Datensatzklassen." },
            { "doclet.help.all_classes.head", "Alle Klassen und Schnittstellen" },
            { "doclet.help.all_packages.body", "Die Seite {0} enth\u00E4lt einen alphabetischen Index aller Packages, die in der Dokumentation enthalten sind." },
            { "doclet.help.all_packages.head", "Alle Packages" },
            { "doclet.help.annotation_interface.declaration", "Deklaration der Annotationsschnittstelle" },
            { "doclet.help.annotation_interface.description", "Beschreibung der Annotationsschnittstelle" },
            { "doclet.help.annotation_interface.intro", "F\u00FCr jede Annotationsschnittstelle ist eine separate Seite mit den folgenden Abschnitten verf\u00FCgbar:" },
            { "doclet.help.annotation_type.declaration", "Deklaration des Annotationstyps" },
            { "doclet.help.annotation_type.description", "Beschreibung des Annotationstyps" },
            { "doclet.help.annotation_type.intro", "F\u00FCr jeden Annotationstyp ist eine separate Seite mit den folgenden Abschnitten verf\u00FCgbar:" },
            { "doclet.help.class_interface.anno", "Annotationsschnittstellen haben erforderliche und optionale Elemente, aber nicht Methoden." },
            { "doclet.help.class_interface.declaration", "Klassen- oder Schnittstellendeklaration" },
            { "doclet.help.class_interface.description", "Klassen- oder Schnittstellenbeschreibung" },
            { "doclet.help.class_interface.enum", "Nur Enum-Klassen haben Enum-Konstanten." },
            { "doclet.help.class_interface.head", "Klasse oder Schnittstelle" },
            { "doclet.help.class_interface.implementations", "Alle bekannten Implementierungsklassen" },
            { "doclet.help.class_interface.inheritance_diagram", "Klassenvererbungsdiagramm" },
            { "doclet.help.class_interface.intro", "F\u00FCr jede Klasse, Schnittstelle, verschachtelte Klasse und verschachtelte Schnittstelle ist eine separate Seite vorhanden. Jede dieser Seiten enth\u00E4lt drei Abschnitte, die aus einer Deklaration und Beschreibung, Mitglieder\u00FCbersichtstabellen und detaillierten Mitgliederbeschreibungen bestehen. Die Eintr\u00E4ge in diesen Abschnitten werden weggelassen, wenn sie leer oder nicht anwendbar sind." },
            { "doclet.help.class_interface.member_order", "Die \u00DCbersichtseintr\u00E4ge sind alphabetisch geordnet, w\u00E4hrend die detaillierten Beschreibungen in der Reihenfolge aufgef\u00FChrt werden, in der sie im Quellcode auftreten. So werden die vom Programmierer festgelegten logischen Gruppierungen beibehalten." },
            { "doclet.help.class_interface.note", "Hinweis:" },
            { "doclet.help.class_interface.property", "Eigenschaften sind ein Feature von JavaFX." },
            { "doclet.help.class_interface.record", "Die Komponenten einer Datensatzklasse werden als Teil der Deklaration der Datensatzklasse angezeigt." },
            { "doclet.help.class_interface.subclasses", "Direkte Unterklassen" },
            { "doclet.help.class_interface.subinterfaces", "Alle bekannten Unterschnittstellen" },
            { "doclet.help.constants.body", "Auf der Seite {0} sind die statischen endg\u00FCltigen Felder und deren Werte aufgef\u00FChrt." },
            { "doclet.help.deprecated.body", "Auf der Seite {0} werden alle APIs aufgef\u00FChrt, die veraltet sind. Die Verwendung einer veralteten API ist nicht empfehlenswert, im Allgemeinen aufgrund von M\u00E4ngeln. In der Regel wird eine Ersatz-API angegeben. Veraltete APIs werden in k\u00FCnftigen Implementierungen m\u00F6glicherweise entfernt." },
            { "doclet.help.enum.class.intro", "F\u00FCr jede Enum-Klasse ist eine separate Seite mit den folgenden Abschnitten verf\u00FCgbar:" },
            { "doclet.help.enum.intro", "F\u00FCr jede Enum-Klasse ist eine separate Seite mit den folgenden Abschnitten verf\u00FCgbar:" },
            { "doclet.help.externalSpecifications.body", "Die Seite {0} listet Referenzen auf externe Spezifikationen auf." },
            { "doclet.help.footnote", "Diese Hilfedatei gilt f\u00FCr die vom Standard-Doclet generierte API-Dokumentation." },
            { "doclet.help.index.body", "Die {0} enth\u00E4lt einen alphabetischen Index aller Klassen, Schnittstellen, Konstruktoren, Methoden und Felder in der Dokumentation sowie \u00DCbersichtsseiten wie {1}." },
            { "doclet.help.index.head", "Index" },
            { "doclet.help.main_heading", "Hilfe zu JavaDoc" },
            { "doclet.help.module.intro", "F\u00FCr jedes Modul ist eine Seite vorhanden, die eine Liste der Packages, Abh\u00E4ngigkeiten von anderen Modulen und Services mit jeweils einer \u00DCbersicht daf\u00FCr enth\u00E4lt. Diese Seiten k\u00F6nnen die folgenden Kategorien enthalten:" },
            { "doclet.help.navigation.head", "Navigation" },
            { "doclet.help.navigation.index", "Mit {0} und dem Suchfeld k\u00F6nnen Sie zu spezifischen Deklarationen und \u00DCbersichtsseiten navigieren, wie {1}" },
            { "doclet.help.navigation.intro", "Ausgehend von der Seite {0} k\u00F6nnen Sie die Dokumentation mithilfe der Links durchsuchen, die sich auf jeder Seite und in der Navigationsleiste oben auf jeder Seite befinden." },
            { "doclet.help.new.body", "Die Seite {0} listet APIs auf, die in neueren Releases hinzugef\u00FCgt wurden." },
            { "doclet.help.other_files.body", "Packages und Module k\u00F6nnen Seiten mit weiteren Informationen zu den Deklarationen in der N\u00E4he enthalten." },
            { "doclet.help.other_files.head", "Weitere Dateien" },
            { "doclet.help.overview.modules.body", "Die Seite {0} ist die Titelseite dieses API-Dokuments und enth\u00E4lt eine Liste aller Module mit einer \u00DCbersicht f\u00FCr jedes Modul. Diese Seite kann auch eine Gesamtbeschreibung des Modulsets enthalten." },
            { "doclet.help.overview.packages.body", "Die Seite {0} ist die Titelseite dieses API-Dokuments und enth\u00E4lt eine Liste aller Packages mit einer \u00DCbersicht f\u00FCr jedes Packages. Diese Seite kann auch eine Gesamtbeschreibung des Packagesets enthalten." },
            { "doclet.help.package.intro", "F\u00FCr jedes Package ist eine Seite vorhanden, die eine Liste der Klassen und Schnittstellen mit jeweils einer \u00DCbersicht daf\u00FCr enth\u00E4lt. Diese Seiten k\u00F6nnen die folgenden Kategorien enthalten:" },
            { "doclet.help.page_kinds.head", "Seitenarten" },
            { "doclet.help.page_kinds.intro", "Die folgenden Abschnitte beschreiben die verschiedenen Seitenarten in dieser Collection." },
            { "doclet.help.preview.body", "Die Seite {0} listet alle Vorschau-APIs auf. Vorschau-APIs k\u00F6nnen in k\u00FCnftigen Implementierungen entfernt werden." },
            { "doclet.help.restricted.body", "Auf der Seite {0} sind alle eingeschr\u00E4nkten Methoden aufgelistet. Eingeschr\u00E4nkte Methoden sind nicht sicher und k\u00F6nnen bei falscher Verwendung die JVM zum Absturz bringen oder zu einer Besch\u00E4digung des Arbeitsspeichers f\u00FChren." },
            { "doclet.help.search.example", "{0} stimmt mit {1} \u00FCberein" },
            { "doclet.help.search.head", "Suchen" },
            { "doclet.help.search.intro", "Sie k\u00F6nnen nach Definitionen von Modulen, Packages, Typen, Feldern, Methoden, Systemeigenschaften und anderen Begriffen suchen, die in der API definiert sind. Dazu k\u00F6nnen Sie den Namen ganz oder teilweise oder optional auch Abk\u00FCrzungen mit Binnenmajuskeln (\"camelCase\") eingeben. Sie k\u00F6nnen auch mehrere durch Leerzeichen getrennte Suchbegriffe angeben. Beispiele:" },
            { "doclet.help.search.refer", "Eine vollst\u00E4ndige Beschreibung der Suchfeatures finden Sie in der {0}." },
            { "doclet.help.search.spec.title", "Javadoc-Suchspezifikation" },
            { "doclet.help.search.spec.url", "https://docs.oracle.com/en/java/javase/{0}/docs/specs/javadoc/javadoc-search-spec.html" },
            { "doclet.help.serial_form.body", "Jede serialisierbare oder externalisierbare Klasse verf\u00FCgt \u00FCber eine Beschreibung der zugeh\u00F6rigen Serialisierungsfelder und -methoden. Diese Informationen sind eher f\u00FCr Implementierer als f\u00FCr Benutzer der API von Interesse. Die Navigationsleiste enth\u00E4lt zwar keinen Link, Sie k\u00F6nnen diese Informationen jedoch abrufen, indem Sie zu einer beliebigen serialisierten Klasse navigieren und im Abschnitt \"Siehe auch\" der Klassenbeschreibung auf \"Serialisierte Form\" klicken." },
            { "doclet.help.systemProperties.body", "Die Seite {0} listet Referenzen auf Systemeigenschaften auf." },
            { "doclet.help.tree.head", "Baum (Klassenhierarchie)" },
            { "doclet.help.tree.intro", "Es gibt eine Seite {0} f\u00FCr alle Packages, und f\u00FCr jedes Package gibt es eine Hierarchie. Jede Hierarchieseite enth\u00E4lt eine Klassen- und eine Schnittstellenliste. Die Klassen sind nach Vererbungsstruktur organisiert, beginnend mit {1}. Die Schnittstellen erben nicht von {1}." },
            { "doclet.help.tree.overview", "Wenn Sie auf der \u00DCbersichtsseite auf \"Baum\" klicken, wird die Hierarchie f\u00FCr alle Packages angezeigt." },
            { "doclet.help.tree.package", "Wenn Sie eine bestimmte Package-, Klassen- oder Schnittstellenseite anzeigen und auf \"Baum\" klicken, wird die Hierarchie nur f\u00FCr dieses Package angezeigt." },
            { "doclet.help.use.body", "F\u00FCr jedes dokumentierte Package sowie jede Klasse oder Schnittstelle ist eine eigene Verwendungsseite vorhanden. Auf dieser Seite werden die Packages, Klassen, Schnittstellen, Methoden, Konstruktoren und Felder aufgelistet, die einen Teil der angegebenen Klasse oder Schnittstelle oder des angegebenen Packages verwenden. Bei der Klasse oder Schnittstelle A enth\u00E4lt die Verwendungsseite die Unterklassen oder Unterschnittstellen von A, als A deklarierte Felder, Methoden, die A zur\u00FCckgeben, Methoden und Konstruktoren mit Parametern des Typs A und Unterklassen oder Unterschnittstellen mit Parametern des Typs A. Sie k\u00F6nnen auf diese Seite zugreifen, indem Sie zun\u00E4chst das Package, die Klasse oder die Schnittstelle aufrufen und anschlie\u00DFend in der Navigationsleiste auf den Link \"Verwendung\" klicken." },
            { "doclet.help.use.head", "Verwendung" },
            { "doclet.in_class", "in Klasse" },
            { "doclet.in_interface", "in Schnittstelle" },
            { "doclet.link.no_reference", "Keine Referenz angegeben" },
            { "doclet.link.see.no_label", "fehlendes Referenzlabel" },
            { "doclet.link.see.reference_invalid", "Ung\u00FCltige Referenz" },
            { "doclet.link.see.reference_not_accessible", "Referenz nicht zug\u00E4nglich: {0}" },
            { "doclet.link.see.reference_not_found", "Referenz nicht gefunden: {0}" },
            { "doclet.module", "Modul" },
            { "doclet.navAnnotationTypeMember", "Element" },
            { "doclet.navAnnotationTypeOptionalMember", "Optional" },
            { "doclet.navAnnotationTypeRequiredMember", "Erforderlich" },
            { "doclet.navClassUse", "Verwendung" },
            { "doclet.navClassesAndInterfaces", "Klassen und Schnittstellen" },
            { "doclet.navConstructor", "Konstruktor" },
            { "doclet.navDeprecated", "Veraltet" },
            { "doclet.navDescription", "Beschreibung" },
            { "doclet.navEnum", "Enum-Konstanten" },
            { "doclet.navField", "Feld" },
            { "doclet.navMethod", "Methode" },
            { "doclet.navModules", "Module" },
            { "doclet.navNavigation", "Navigation" },
            { "doclet.navNested", "Verschachtelt" },
            { "doclet.navPackages", "Packages" },
            { "doclet.navPages", "Seiten" },
            { "doclet.navProperty", "Eigenschaft" },
            { "doclet.navServices", "Services" },
            { "doclet.not.exhaustive", "(nicht umfassend)" },
            { "doclet.package", "Package" },
            { "doclet.references", "{0} Referenzen" },
            { "doclet.search.browser_info", "Mit der URL-Vorlage unten k\u00F6nnen Sie diese Seite als Suchmaschine in Browsern konfigurieren, die dieses Feature unterst\u00FCtzen. Das Feature wurde erfolgreich mit Google Chrome und Mozilla Firefox getestet. Beachten Sie, dass andere Browser dieses Feature m\u00F6glicherweise nicht unterst\u00FCtzen oder ein anderes URL-Format erfordern." },
            { "doclet.search.help_page_info", "Die {0} enth\u00E4lt eine Einf\u00FChrung in den Umfang und die Syntax der JavaDoc-Suche." },
            { "doclet.search.help_page_link", "Hilfeseite" },
            { "doclet.search.keyboard_info", "Sie k\u00F6nnen die <STRG>- oder <CMD>-Taste zusammen mit den Pfeiltasten nach links und rechts verwenden, um zwischen Ergebnisregisterkarten auf dieser Seite zu wechseln." },
            { "doclet.search.main_heading", "Suchen" },
            { "doclet.search.redirect", "Zum ersten Ergebnis umleiten" },
            { "doclet.search.show_more", "Zus\u00E4tzliche Ressourcen" },
            { "doclet.see.nested_link", "Tag {0}: Verschachtelter Link" },
            { "doclet.systemProperties", "Systemeigenschaften" },
            { "doclet.systemPropertiesSummary", "Systemeigenschaften - \u00DCbersicht" },
            { "doclet.tag.invalid", "ung\u00FCltiges @{0}" },
            { "doclet.tag.invalid_input", "Ung\u00FCltige Eingabe: \"{0}\"" },
            { "doclet.tag.invalid_usage", "Ung\u00FCltige Verwendung des Tags {0}" },
            { "doclet.throws.reference_bad_type", "Kein Ausnahmetyp: {0}" },
            { "doclet.throws.reference_not_found", "Ausnahmetyp nach Name nicht gefunden" },
            { "doclet.usage.add-script.description", "F\u00FCgt der generierten Dokumentation eine Skriptdatei hinzu" },
            { "doclet.usage.add-script.parameters", "<Datei>" },
            { "doclet.usage.add-stylesheet.description", "F\u00FCgt der generierten Dokumentation eine Stylesheet-Datei hinzu" },
            { "doclet.usage.add-stylesheet.parameters", "<Datei>" },
            { "doclet.usage.allow-script-in-comments.description", "JavaScript in Optionen und Kommentaren zulassen" },
            { "doclet.usage.author.description", "@author-Abs\u00E4tze aufnehmen" },
            { "doclet.usage.bottom.description", "Unteren Text f\u00FCr jede Seite aufnehmen" },
            { "doclet.usage.bottom.parameters", "<HTML-Code>" },
            { "doclet.usage.charset.description", "Zeichensatz f\u00FCr plattform\u00FCbergreifende Anzeige der generierten Dokumentation" },
            { "doclet.usage.charset.parameters", "<Zeichensatz>" },
            { "doclet.usage.d.description", "Zielverzeichnis f\u00FCr Ausgabedateien" },
            { "doclet.usage.d.parameters", "<Verzeichnis>" },
            { "doclet.usage.date.description", "Gibt den Wert f\u00FCr den Zeitstempel der generierten Seiten im ISO 8601-Format an" },
            { "doclet.usage.date.parameters", "<date-and-time>" },
            { "doclet.usage.docencoding.description", "Zeichensatzcodierung f\u00FCr die Ausgabe angeben" },
            { "doclet.usage.docencoding.parameters", "<Name>" },
            { "doclet.usage.docfilessubdirs.description", "doc-file-Unterverzeichnisse rekursiv kopieren" },
            { "doclet.usage.doctitle.description", "Titel f\u00FCr die \u00DCberblickseite aufnehmen" },
            { "doclet.usage.doctitle.parameters", "<HTML-Code>" },
            { "doclet.usage.excludedocfilessubdir.description", "doc-files-Unterverzeichnisse mit angegebenem Namen ausschlie\u00DFen.\n\":\" kann \u00FCberall im Argument als Trennzeichen verwendet werden." },
            { "doclet.usage.excludedocfilessubdir.parameters", "<name>,<name>,..." },
            { "doclet.usage.footer.description", "Footertext f\u00FCr jede Seite aufnehmen" },
            { "doclet.usage.footer.parameters", "<HTML-Code>" },
            { "doclet.usage.frames.description", "Aktiviert die Verwendung von Frames in der generierten Ausgabe" },
            { "doclet.usage.group.description", "Angegebene Elemente auf \u00DCberblickseite gruppieren.\n\":\" kann \u00FCberall im Argument als Trennzeichen verwendet werden." },
            { "doclet.usage.group.parameters", "<name> <g1>,<g2>..." },
            { "doclet.usage.header.description", "Headertext f\u00FCr jede Seite aufnehmen" },
            { "doclet.usage.header.parameters", "<HTML-Code>" },
            { "doclet.usage.helpfile.description", "Datei aufnehmen, zu der der Hilfelink verlinkt" },
            { "doclet.usage.helpfile.parameters", "<Datei>" },
            { "doclet.usage.html5.description", "Generiert eine HTML 5-Ausgabe. Diese Option wird nicht mehr ben\u00F6tigt." },
            { "doclet.usage.javafx.description", "Aktiviert die JavaFX-Funktionalit\u00E4t" },
            { "doclet.usage.keywords.description", "HTML-Metatags mit Informationen zu Package, Klasse und Member aufnehmen" },
            { "doclet.usage.legal-notices.description", "Steuert die rechtlichen Hinweise in der generierten Ausgabe" },
            { "doclet.usage.legal-notices.parameters", "'default' | 'none' | <Verzeichnis>" },
            { "doclet.usage.link-modularity-mismatch.description", "Meldet externe Dokumentation mit der falschen Modularit\u00E4t mit einer\nWarn- oder Informationsmeldung. Das Standardverhalten ist\nWarnen." },
            { "doclet.usage.link-modularity-mismatch.parameters", "(warn|info)" },
            { "doclet.usage.link-platform-properties.description", "Link zu Plattformdokumentations-URLs, die in der Eigenschaftendatei auf <URL> deklariert sind" },
            { "doclet.usage.link-platform-properties.parameters", "< URL>" },
            { "doclet.usage.link.description", "Links zur javadoc-Ausgabe unter <url> erstellen" },
            { "doclet.usage.link.parameters", "< URL>" },
            { "doclet.usage.linkoffline.description", "Link zu Dokumenten unter <url> mit Packageliste unter <url2> erstellen" },
            { "doclet.usage.linkoffline.parameters", "<URL1> <URL2>" },
            { "doclet.usage.linksource.description", "Quelle in HTML generieren" },
            { "doclet.usage.main-stylesheet.description", "Datei zum \u00C4ndern des Stils der generierten Dokumentation" },
            { "doclet.usage.main-stylesheet.parameters", "<Datei>" },
            { "doclet.usage.no-fonts.description", "Keine Standardwebschriftarten in generierte Dokumentation aufnehmen" },
            { "doclet.usage.no-frames.description", "Deaktiviert die Verwendung von Frames in der generierten Ausgabe (Standard)" },
            { "doclet.usage.no-module-directories.description", "Gruppiert Dateien f\u00FCr die Moduldokumentation nicht in \nmodulspezifischen Verzeichnisse" },
            { "doclet.usage.no-platform-links.description", "Generiert keine Links zur Plattformdokumentation" },
            { "doclet.usage.nocomment.description", "Beschreibung und Tags unterdr\u00FCcken und nur Deklarationen generieren" },
            { "doclet.usage.nodeprecated.description", "@deprecated-Informationen nicht aufnehmen" },
            { "doclet.usage.nodeprecatedlist.description", "Veraltet-Liste nicht generieren" },
            { "doclet.usage.nohelp.description", "Hilfelink nicht generieren" },
            { "doclet.usage.noindex.description", "Index nicht generieren" },
            { "doclet.usage.nonavbar.description", "Navigationsleiste nicht generieren" },
            { "doclet.usage.nooverview.description", "\u00DCberblickseiten nicht generieren" },
            { "doclet.usage.noqualifier.description", "Liste der Qualifier aus der Ausgabe ausschlie\u00DFen.\n\":\" kann \u00FCberall im Argument als Trennzeichen verwendet werden." },
            { "doclet.usage.noqualifier.parameters", "<name1>,<name2>,..." },
            { "doclet.usage.nosince.description", "@since-Informationen nicht aufnehmen" },
            { "doclet.usage.notimestamp.description", "Ausgeblendeten Zeitstempel nicht aufnehmen" },
            { "doclet.usage.notree.description", "Klassenhierarchie nicht generieren" },
            { "doclet.usage.override-methods.description", "Au\u00DFer Kraft gesetzte Methoden im Abschnitt \"detail\" oder \"summary\" dokumentieren.\nDer Standardwert ist \"detail\"." },
            { "doclet.usage.override-methods.parameters", "(detail|summary)" },
            { "doclet.usage.overview.description", "\u00DCberblickdokumentation aus HTML-Datei lesen" },
            { "doclet.usage.overview.parameters", "<Datei>" },
            { "doclet.usage.serialwarn.description", "Warnung wegen @serial-Tag generieren" },
            { "doclet.usage.since-label.description", "Liefert Text f\u00FCr die \u00DCberschrift der Seite \"Neue API\"" },
            { "doclet.usage.since-label.parameters", "<Text>" },
            { "doclet.usage.since.description", "Dokumentiert die neue und die veraltete API in den angegebenen Releases" },
            { "doclet.usage.since.parameters", "<Release>(,<Release>)*" },
            { "doclet.usage.snippet-path.description", "Der Pfad f\u00FCr externe Snippets" },
            { "doclet.usage.snippet-path.parameters", "<Pfad>" },
            { "doclet.usage.sourcetab.description", "Anzahl der Leerzeichen angeben, die jedes Register in der Quelle beansprucht" },
            { "doclet.usage.sourcetab.parameters", "<Tabulatorl\u00E4nge>" },
            { "doclet.usage.spec-base-url", "<URL>" },
            { "doclet.usage.spec-base-url.description", "Basis-URL f\u00FCr relative URLs in @spec-Tags angeben" },
            { "doclet.usage.splitindex.description", "Index in eine Datei pro Buchstabe aufteilen" },
            { "doclet.usage.tag.description", "Benutzerdefinierte Tags mit einem Argument angeben" },
            { "doclet.usage.tag.parameters", "<Name>:<Positionen>:<Header>" },
            { "doclet.usage.taglet.description", "Vollqualifizierter Name des zu registrierenden Taglets" },
            { "doclet.usage.tagletpath.description", "Pfad zu Taglets" },
            { "doclet.usage.top.description", "Oberen Text f\u00FCr jede Seite aufnehmen" },
            { "doclet.usage.top.parameters", "<HTML-Code>" },
            { "doclet.usage.use.description", "Verwendungsseiten f\u00FCr Klassen und Packages erstellen" },
            { "doclet.usage.version.description", "@version-Abs\u00E4tze aufnehmen" },
            { "doclet.usage.windowtitle.description", "Browserfenstertitel f\u00FCr die Dokumentation" },
            { "doclet.usage.windowtitle.parameters", "<Text>" },
            { "doclet.usage.xdoclint-extended.description", "Bestimmte Pr\u00FCfungen f\u00FCr Probleme in javadoc-Kommentaren aktivieren\noder deaktivieren, wobei <group> einen der folgenden Werte hat:\naccessibility, html, missing, reference oder syntax." },
            { "doclet.usage.xdoclint-extended.parameters", "(all|none|[-]<Gruppe>)" },
            { "doclet.usage.xdoclint-package.description", "Pr\u00FCfungen in bestimmten Packages aktivieren oder deaktivieren.\n<packages> ist eine durch Komma getrennte Liste von Packagebezeichnern.\nEin Packagebezeichner ist entweder ein vollst\u00E4ndiger Name oder ein Namenspr\u00E4fix\neines Packages, gefolgt von .*, und bezieht sich auf alle Unterpackages\ndes angegebenen Packages. Stellen Sie dem Packagebezeichner - voran,\num Pr\u00FCfungen f\u00FCr die angegebenen Packages zu deaktivieren." },
            { "doclet.usage.xdoclint-package.parameters", "([-]<Packages>)" },
            { "doclet.usage.xdoclint.description", "Empfohlene Pr\u00FCfungen f\u00FCr Probleme in javadoc-Kommentaren aktivieren" },
            { "doclet.usage.xdocrootparent.description", "Ersetzt alle Vorkommen von @docRoot gefolgt von /.. in doc-Kommentaren durch\n<url>" },
            { "doclet.usage.xdocrootparent.parameters", "< URL>" },
        };
    }
}
